Installation
^^^^^^^^^^^^

Installation with pip through PyPI is recommended for all users.

Install via Pip
==============

The easiest method to install and upgrade Forallpeople is using pip.

.. code-block:: console
    $ pip install forallpeople

To upgrade to latest version:

.. code-block:: console
    $ pip install forallpeople --upgrade
    
